@@ -13,24 +13,25 @@
 #'   documentation for related model class in [model_parameters()].
 #' @param column_names Character vector with strings that should be used as
 #'   column headers. Must be of same length as number of models in `...`.
-#' @param ci_method Method for computing degrees of freedom for p values
+#' @param ci_method Method for computing degrees of freedom for p-values
 #'   and confidence intervals (CI). See documentation for related model class
 #'   in [model_parameters()].
 #' @param style String, indicating which style of output is requested. Following
 #'   templates are possible:
-#'   \itemize{
-#'     \item `"ci"`: Estimate and confidence intervals, no asterisks for p-values.
-#'     \item `"se"`: Estimate and standard errors, no asterisks for p-values.
-#'     \item `"ci_p"`: Estimate, confidence intervals and asterisks for p-values.
-#'     \item `"se_p"`: Estimate, standard errors and asterisks for p-values.
-#'     \item `"ci_p2"`: Estimate, confidence intervals and numeric p-values, in two columns.
-#'     \item `"se_p2"`: Estimate, standard errors and numeric p-values, in two columns.
-#'   }
+#'
+#'  - `"ci"`: Estimate and confidence intervals, no asterisks for p-values.
+#'  - `"se"`: Estimate and standard errors, no asterisks for p-values.
+#'  - `"ci_p"`: Estimate, confidence intervals and asterisks for p-values.
+#'  - `"se_p"`: Estimate, standard errors and asterisks for p-values.
+#'  - `"ci_p2"`: Estimate, confidence intervals and numeric p-values, in two columns.
+#'  - `"se_p2"`: Estimate, standard errors and numeric p-values, in two columns.
+#'
 #' @inheritParams model_parameters.default
 #' @inheritParams model_parameters.cpglmm
 #' @inheritParams print.parameters_model
 #'
 #' @details
+#'
 #' This function is in an early stage and does not yet cope with more complex
 #' models, and probably does not yet properly render all model components. It
 #' should also be noted that when including models with interaction terms, not
@@ -83,7 +84,7 @@ compare_parameters <- function(...,
 
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    message(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."))
+    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -147,10 +148,21 @@ compare_parameters <- function(...,
   m <- lapply(1:length(models), function(i) {
     model <- models[[i]]
     model_name <- model_names[[i]]
-    # model parameters
+
     if (inherits(model, "parameters_model")) {
+
+      # we already have model parameters object...
       dat <- model
     } else {
+
+      # set default-ci_type for Bayesian models
+      if (.is_bayesian_model(model) && !ci_method %in% c("hdi", "quantile", "ci", "eti", "si", "bci", "bcai")) {
+        ci_method_tmp <- "eti"
+      } else {
+        ci_method_tmp <- ci_method
+      }
+
+      # here we have a model object that needs to be passed to model_parameters
       dat <- model_parameters(
         model,
         ci = ci,
@@ -158,37 +170,41 @@ compare_parameters <- function(...,
         component = component,
         standardize = standardize,
         exponentiate = exponentiate,
-        ci_method = ci_method,
+        ci_method = ci_method_tmp,
         p_adjust = p_adjust,
         keep = keep,
         drop = drop,
         verbose = verbose
       )
     }
+
     # set specific names for coefficient column
     coef_name <- attributes(dat)$coefficient_name
     if (!is.null(coef_name)) {
       colnames(dat)[colnames(dat) == "Coefficient"] <- coef_name
     }
+
     # set pretty parameter names
     dat <- .set_pretty_names(dat)
+
     # make sure we have a component-column, for merging
     if (!"Component" %in% colnames(dat)) {
       dat$Component <- "conditional"
     }
+
     # add zi-suffix to parameter names
     if (any(dat$Component == "zero_inflated")) {
       dat$Parameter[dat$Component == "zero_inflated"] <- paste0(dat$Parameter[dat$Component == "zero_inflated"], " (zi)")
     }
+
     # add suffix
     ignore <- colnames(dat) %in% c("Parameter", "Component")
     colnames(dat)[!ignore] <- paste0(colnames(dat)[!ignore], ".", model_name)
+
     # save model number, for sorting
     dat$model <- i
     dat$model[.in_intercepts(dat$Parameter)] <- 0
-    # add index for row order. needed later, because "merge()" sometimes
-    # messes up the correct row sorting, despite setting "sort = FALSE"
-    dat$.row_index <- 1:nrow(dat)
+
     dat
   })
 
@@ -196,12 +212,7 @@ compare_parameters <- function(...,
   names(object_attributes) <- model_names
 
   # merge all data frames
-  all_models <- suppressWarnings(Reduce(function(x, y) merge(x, y, all = TRUE, sort = FALSE, by = c("Parameter", "Component", ".row_index")), m))
-
-  # fix row order
-  row_order <- order(all_models$.row_index)
-  all_models <- all_models[row_order, ]
-  all_models$.row_index <- NULL
+  all_models <- suppressWarnings(Reduce(function(x, y) merge(x, y, all = TRUE, sort = FALSE, by = c("Parameter", "Component")), m))
 
   # find columns with model numbers and create new variable "params_order",
   # which is pasted together of all model-column indices. Take lowest index of
@@ -212,7 +223,7 @@ compare_parameters <- function(...,
   all_models <- all_models[order(params_order), ]
   all_models[model_cols] <- NULL
 
-  attr(all_models, "model_names") <- gsub("\"", "", unlist(lapply(model_names, .safe_deparse)), fixed = TRUE)
+  attr(all_models, "model_names") <- gsub("\"", "", unlist(lapply(model_names, insight::safe_deparse)), fixed = TRUE)
   attr(all_models, "output_style") <- style
   attr(all_models, "all_attributes") <- object_attributes
   class(all_models) <- c("compare_parameters", "see_compare_parameters", unique(class(all_models)))
@@ -226,14 +237,12 @@ compare_parameters <- function(...,
 compare_models <- compare_parameters
 
 
-
-
-
 # helper ----------------------------
 
 
 .set_pretty_names <- function(x) {
   att <- attributes(x)
+
   if (!is.null(att$pretty_names)) {
     # remove strings with NA names
     att$pretty_names <- att$pretty_names[!is.na(names(att$pretty_names))]
@@ -258,5 +267,6 @@ compare_models <- compare_parameters
   if (!is.null(x$Parameter)) {
     x$Parameter <- gsub("]", ")", gsub("[", "(", x$Parameter, fixed = TRUE), fixed = TRUE)
   }
+
   x
 }
