@@ -42,6 +42,7 @@
   names(parameters) <- gsub("LR Chisq", "Chi2", names(parameters), fixed = TRUE)
   names(parameters) <- gsub("Chisq", "Chi2", names(parameters), fixed = TRUE)
   names(parameters) <- gsub("Chi.sq", "Chi2", names(parameters), fixed = TRUE)
+  names(parameters) <- gsub("Chi.Square", "Chi2", names(parameters), fixed = TRUE)
   names(parameters) <- gsub("Chi-Square", "Chi2", names(parameters), fixed = TRUE)
   # other
   names(parameters) <- gsub("logLik", "Log_Likelihood", names(parameters), fixed = TRUE)
@@ -83,7 +84,7 @@
 
 .extract_anova_aov <- function(model) {
   parameters <- as.data.frame(summary(model)[[1]])
-  parameters$Parameter <- trimws(row.names(parameters))
+  parameters$Parameter <- insight::trim_ws(row.names(parameters))
   parameters
 }
 
@@ -92,7 +93,7 @@
 
 .extract_anova_manova <- function(model) {
   parameters <- as.data.frame(summary(model)$stats)
-  parameters$Parameter <- trimws(row.names(parameters))
+  parameters$Parameter <- insight::trim_ws(row.names(parameters))
   parameters[["den Df"]] <- NULL
   parameters[["num Df"]] <- NULL
   parameters
@@ -105,7 +106,7 @@
   s <- summary(model)
   out <- do.call(rbind, lapply(names(s), function(i) {
     parameters <- as.data.frame(s[[i]])
-    parameters$Parameter <- trimws(row.names(parameters))
+    parameters$Parameter <- insight::trim_ws(row.names(parameters))
     parameters$Response <- gsub("\\s*Response ", "", i)
     parameters
   }))
@@ -137,7 +138,7 @@
     } else {
       temp <- as.data.frame(aov_summary[[1]])
     }
-    temp$Parameter <- trimws(row.names(temp))
+    temp$Parameter <- insight::trim_ws(row.names(temp))
     temp$Group <- i
     temp
   }))
@@ -150,11 +151,11 @@
 
 .extract_anova_anova <- function(model) {
   parameters <- as.data.frame(model)
-  parameters$Parameter <- trimws(row.names(parameters))
+  parameters$Parameter <- insight::trim_ws(row.names(parameters))
   # Deal with anovas of models
   if (length(attributes(model)$heading) == 2) {
     info <- attributes(model)$heading[[2]]
-    if (grepl("Model", info)) {
+    if (grepl("Model", info, fixed = TRUE)) {
       parameters$Parameter <- unlist(strsplit(info, "\n", fixed = TRUE))
     }
   } else if (length(attributes(model)$heading) > 2) {
