@@ -4,7 +4,7 @@ model_parameters.bamlss <- function(model,
                                     centrality = "median",
                                     dispersion = FALSE,
                                     ci = .95,
-                                    ci_method = "hdi",
+                                    ci_method = "eti",
                                     test = c("pd", "rope"),
                                     rope_range = "default",
                                     rope_ci = 0.95,
@@ -16,8 +16,6 @@ model_parameters.bamlss <- function(model,
                                     parameters = keep,
                                     verbose = TRUE,
                                     ...) {
-  modelinfo <- insight::model_info(model)
-
   # Processing
   params <- .extract_parameters_bayesian(
     model,
