@@ -5,8 +5,8 @@ model_parameters.epi.2by2 <- function(model, verbose = TRUE, ...) {
   colnames(params)[2] <- "Coefficient"
 
   # get coefficients including CI
-  coef_names <- grepl(".strata.wald", names(model$massoc), fixed = TRUE)
-  cf <- model$massoc[coef_names]
+  coef_names <- grepl("^([^NNT]*)(\\.strata\\.wald)", names(model$massoc.detail), perl = TRUE)
+  cf <- model$massoc.detail[coef_names]
   names(cf) <- gsub(".strata.wald", "", names(cf), fixed = TRUE)
 
   # extract CI
@@ -31,9 +31,10 @@ model_parameters.epi.2by2 <- function(model, verbose = TRUE, ...) {
   pretty_names[pretty_names == "AFRisk"] <- "Attributable Fraction in Exposed (%)"
   pretty_names[pretty_names == "PAFRisk"] <- "Attributable Fraction in Population (%)"
 
-  stats <- model$massoc$chisq.strata
-  attr(params, "footer_text") <- paste0("Test that Odds Ratio = 1: Chi2(", stats[["df"]], ") = ", insight::format_value(stats[["test.statistic"]]), ", ", insight::format_p(stats[["p.value"]]))
+  stats <- model$massoc.detail$chi2.strata.uncor
+  attr(params, "footer_text") <- paste0("Test that Odds Ratio = 1: Chi2(", stats[["df"]], ") = ", insight::format_value(stats[["test.statistic"]]), ", ", insight::format_p(stats[["p.value.2s"]]))
   attr(params, "pretty_names") <- stats::setNames(pretty_names, params$Parameter)
+  attr(params, "no_caption") <- TRUE
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
   params
 }
