@@ -16,7 +16,7 @@ model_parameters.metaplus <- function(model,
                                       ...) {
   if (!missing(ci)) {
     if (isTRUE(verbose)) {
-      message("'metaplus' models do not support other levels for confidence intervals than 0.95. Argument 'ci' is ignored.")
+      message(insight::format_message("'metaplus' models do not support other levels for confidence intervals than 0.95. Argument 'ci' is ignored."))
     }
     ci <- .95
   }
@@ -83,7 +83,7 @@ model_parameters.metaplus <- function(model,
 
   # no df
   out$df_error <- NULL
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   attr(out, "measure") <- "Estimate"
 
   if (!"Method" %in% names(out)) {
@@ -141,11 +141,10 @@ ci.metaplus <- function(x, ...) {
 ###### .meta_random -------------------
 
 
-#' @importFrom insight get_priors
 #' @export
 model_parameters.meta_random <- function(model,
                                          ci = .95,
-                                         ci_method = "hdi",
+                                         ci_method = "eti",
                                          exponentiate = FALSE,
                                          include_studies = TRUE,
                                          verbose = TRUE,
@@ -153,7 +152,7 @@ model_parameters.meta_random <- function(model,
 
   # process arguments
   params <- as.data.frame(model$estimates)
-  ci_method <- match.arg(ci_method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(ci_method, choices = c("hdi", "eti", "quantile"))
 
   # parameters of studies included
   study_params <- model$data
@@ -231,7 +230,7 @@ model_parameters.meta_random <- function(model,
 
   # final atributes
   attr(out, "measure") <- "Estimate"
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   class(out) <- c("parameters_model", "see_parameters_model", class(params))
 
   if (!"Method" %in% names(out)) {
@@ -258,10 +257,10 @@ standard_error.meta_random <- function(model, ...) {
 
 
 #' @export
-ci.meta_random <- function(x, method = "hdi", ...) {
+ci.meta_random <- function(x, method = "eti", ...) {
   # process arguments
   params <- as.data.frame(x$estimates)
-  ci_method <- match.arg(method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(method, choices = c("hdi", "eti", "quantile"))
 
   # extract ci-level and find ci-columns
   ci <- .meta_bma_extract_ci(params)
@@ -305,7 +304,7 @@ ci.meta_fixed <- ci.meta_random
 #' @export
 model_parameters.meta_bma <- function(model,
                                       ci = .95,
-                                      ci_method = "hdi",
+                                      ci_method = "eti",
                                       exponentiate = FALSE,
                                       include_studies = TRUE,
                                       verbose = TRUE,
@@ -313,7 +312,7 @@ model_parameters.meta_bma <- function(model,
 
   # process arguments
   params <- as.data.frame(model$estimates)
-  ci_method <- match.arg(ci_method, choices = c("hdi", "eti"))
+  ci_method <- match.arg(ci_method, choices = c("hdi", "eti", "quantile"))
 
   # parameters of studies included
   study_params <- model$meta$fixed$data
@@ -377,7 +376,7 @@ model_parameters.meta_bma <- function(model,
 
   # final attributes
   attr(out, "measure") <- "Estimate"
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   class(out) <- c("parameters_model", "see_parameters_model", class(params))
 
   if (!"Method" %in% names(out)) {
