@@ -44,7 +44,7 @@ standard_error.mvord <- function(model, component = c("all", "conditional", "thr
 
   params <- params[c("Parameter", "SE", "Component", "Response")]
 
-  if (.n_unique(params$Response) == 1) {
+  if (insight::n_unique(params$Response) == 1) {
     params$Response <- NULL
   }
 
@@ -70,7 +70,7 @@ p_value.mvord <- function(model, component = c("all", "conditional", "thresholds
 
   params <- params[c("Parameter", "p", "Component", "Response")]
 
-  if (.n_unique(params$Response) == 1) {
+  if (insight::n_unique(params$Response) == 1) {
     params$Response <- NULL
   }
 
@@ -88,6 +88,6 @@ simulate_model.mvord <- function(model, iterations = 1000, component = c("all",
   out <- .simulate_model(model, iterations, component = component)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   out
 }
