@@ -54,15 +54,12 @@ model_parameters.clmm <- model_parameters.cpglmm
 # CI ---------------------
 
 
-#' @export
-ci.clm <- ci.tobit
+## TODO residual df?
 
-
-#' @rdname ci.merMod
 #' @export
 ci.clm2 <- function(x, ci = .95, component = c("all", "conditional", "scale"), ...) {
   component <- match.arg(component)
-  ci_wald(model = x, ci = ci, dof = Inf, component = component)
+  .ci_generic(model = x, ci = ci, dof = Inf, component = component)
 }
 
 
@@ -74,10 +71,9 @@ ci.clmm2 <- ci.clm2
 # standard errors -----------------
 
 
-#' @rdname standard_error
 #' @export
-standard_error.clm2 <- function(model, component = c("all", "conditional", "scale"), ...) {
-  component <- match.arg(component)
+standard_error.clm2 <- function(model, component = "all", ...) {
+  component <- match.arg(component, choices = c("all", "conditional", "scale"))
   stats <- .get_se_from_summary(model)
   parms <- insight::get_parameters(model, component = component)
 
@@ -136,7 +132,7 @@ simulate_model.clm2 <- function(model,
   out <- .simulate_model(model, iterations, component = component)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   out
 }
 
