@@ -11,29 +11,29 @@
   if (style == "minimal") {
     ci_col <- colnames(x)[grepl(" CI$", colnames(x)) | colnames(x) == "CI"]
     param_col <- colnames(x)[1]
-    x[[param_col]] <- trimws(paste0(x[[param_col]], linesep, x[[ci_col]]))
+    x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], linesep, x[[ci_col]]))
     x <- x[c(param_col, "p")]
     colnames(x) <- paste0(colnames(x), " (", modelname, ")")
   } else if (style %in% c("ci_p", "ci")) {
     ci_col <- colnames(x)[grepl(" CI$", colnames(x)) | colnames(x) == "CI"]
     param_col <- colnames(x)[1]
-    x[[param_col]] <- trimws(paste0(x[[param_col]], x$p_stars, linesep, x[[ci_col]]))
+    x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], x$p_stars, linesep, x[[ci_col]]))
     x <- x[param_col]
     colnames(x) <- modelname
   } else if (style %in% c("se_p", "se")) {
     param_col <- colnames(x)[1]
-    x[[param_col]] <- trimws(paste0(x[[param_col]], x$p_stars, linesep, "(", x$SE, ")"))
+    x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], x$p_stars, linesep, "(", x$SE, ")"))
     x <- x[param_col]
     colnames(x) <- modelname
   } else if (style %in% c("ci_p2")) {
     ci_col <- colnames(x)[grepl(" CI$", colnames(x)) | colnames(x) == "CI"]
     param_col <- colnames(x)[1]
-    x[[param_col]] <- trimws(paste0(x[[param_col]], linesep, x[[ci_col]]))
+    x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], linesep, x[[ci_col]]))
     x <- x[c(param_col, "p")]
     colnames(x) <- paste0(colnames(x), " (", modelname, ")")
   } else if (style %in% c("se_p2")) {
     param_col <- colnames(x)[1]
-    x[[param_col]] <- trimws(paste0(x[[param_col]], linesep, "(", x$SE, ")"))
+    x[[param_col]] <- insight::trim_ws(paste0(x[[param_col]], linesep, "(", x$SE, ")"))
     x <- x[c(param_col, "p")]
     colnames(x) <- paste0(colnames(x), " (", modelname, ")")
   }
@@ -142,6 +142,17 @@
 }
 
 
+# The coefficient column in the printed output is renamed, based on the model.
+# But for instance, for random effects, however, which are on a different scale,
+# we want a different name for this column. Since print.parameters_model() splits
+# components into different tables, we change the column name for those "tables"
+# that contain the random effects or zero-inflated parameters
+
+.all_coefficient_types <- function() {
+  c("Odds Ratio", "Risk Ratio", "IRR", "Log-Odds", "Log-Mean", "Probability", "Marginal Means", "Estimated Counts", "Ratio")
+}
+
+
 
 
 # helper to format the header / subheader of different model components --------------
@@ -222,7 +233,7 @@
   )
 
   if (grepl("^conditional\\.(r|R)andom_variances", component_name)) {
-    component_name <- trimws(gsub("^conditional\\.(r|R)andom_variances(\\.)*", "", component_name))
+    component_name <- insight::trim_ws(gsub("^conditional\\.(r|R)andom_variances(\\.)*", "", component_name))
     if (nchar(component_name) == 0) {
       component_name <- "Random Effects Variances"
     } else {
@@ -230,7 +241,7 @@
     }
   }
   if (grepl("^conditional\\.(r|R)andom", component_name)) {
-    component_name <- trimws(gsub("^conditional\\.(r|R)andom(\\.)*", "", component_name))
+    component_name <- insight::trim_ws(gsub("^conditional\\.(r|R)andom(\\.)*", "", component_name))
     if (nchar(component_name) == 0) {
       component_name <- ifelse(ran_pars, "Random Effects Variances", "Random Effects (Count Model)")
     } else {
@@ -238,7 +249,7 @@
     }
   }
   if (grepl("^zero_inflated\\.(r|R)andom", component_name)) {
-    component_name <- trimws(gsub("^zero_inflated\\.(r|R)andom(\\.)*", "", component_name))
+    component_name <- insight::trim_ws(gsub("^zero_inflated\\.(r|R)andom(\\.)*", "", component_name))
     if (nchar(component_name) == 0) {
       component_name <- "Random Effects (Zero-Inflated Model)"
     } else {
@@ -474,11 +485,11 @@
     x$Response <- NULL
   }
   split_by <- ""
-  split_by <- c(split_by, ifelse("Component" %in% names(x) && .n_unique(x$Component) > 1, "Component", ""))
-  split_by <- c(split_by, ifelse("Effects" %in% names(x) && .n_unique(x$Effects) > 1, "Effects", ""))
-  split_by <- c(split_by, ifelse("Response" %in% names(x) && .n_unique(x$Response) > 1, "Response", ""))
-  split_by <- c(split_by, ifelse("Group" %in% names(x) && .n_unique(x$Group) > 1, "Group", ""))
-  split_by <- c(split_by, ifelse("Subgroup" %in% names(x) && .n_unique(x$Subgroup) > 1, "Subgroup", ""))
+  split_by <- c(split_by, ifelse("Component" %in% names(x) && insight::n_unique(x$Component) > 1, "Component", ""))
+  split_by <- c(split_by, ifelse("Effects" %in% names(x) && insight::n_unique(x$Effects) > 1, "Effects", ""))
+  split_by <- c(split_by, ifelse("Response" %in% names(x) && insight::n_unique(x$Response) > 1, "Response", ""))
+  split_by <- c(split_by, ifelse("Group" %in% names(x) && insight::n_unique(x$Group) > 1, "Group", ""))
+  split_by <- c(split_by, ifelse("Subgroup" %in% names(x) && insight::n_unique(x$Subgroup) > 1, "Subgroup", ""))
 
   split_by <- split_by[nchar(split_by) > 0]
   split_by
@@ -542,7 +553,7 @@
   # make sure we have correct order of levels from split-factor
   if (!is.null(attributes(x)$model_class) && all(attributes(x)$model_class == "mediate")) {
     x$Component <- factor(x$Component, levels = c("control", "treated", "average", "Total Effect"))
-    x$Parameter <- trimws(gsub("(.*)\\((.*)\\)$", "\\1", x$Parameter))
+    x$Parameter <- insight::trim_ws(gsub("(.*)\\((.*)\\)$", "\\1", x$Parameter))
   } else {
     x[split_column] <- lapply(x[split_column], function(i) {
       if (!is.factor(i)) i <- factor(i, levels = unique(i))
@@ -673,11 +684,11 @@
     }
 
     # rename columns for random part
-    if (grepl("random", type) && any(colnames(tables[[type]]) %in% .all_coefficient_types())) {
+    if (grepl("random", type, fixed = TRUE) && any(colnames(tables[[type]]) %in% .all_coefficient_types())) {
       colnames(tables[[type]])[colnames(tables[[type]]) %in% .all_coefficient_types()] <- "Coefficient"
     }
 
-    if (grepl("random", type) && isTRUE(ran_pars)) {
+    if (grepl("random", type, fixed = TRUE) && isTRUE(ran_pars)) {
       tables[[type]]$CI <- NULL
     }
 
@@ -695,18 +706,18 @@
     component_header <- .format_model_component_header(x, type, split_column, is_zero_inflated, is_ordinal_model, is_multivariate, ran_pars, formatted_table)
 
     # exceptions for random effects
-    if (.n_unique(formatted_table$Group) == 1) {
+    if (insight::n_unique(formatted_table$Group) == 1) {
       component_header$subheader1 <- paste0(component_header$subheader1, " (", formatted_table$Group, ")")
       formatted_table$Group <- NULL
     }
 
     # remove non-necessary columns
-    if (.n_unique(formatted_table$Component) == 1) {
+    if (insight::n_unique(formatted_table$Component) == 1) {
       formatted_table$Component <- NULL
     }
 
     # no column with CI-level in output
-    if (!is.null(formatted_table$CI) && .n_unique(formatted_table$CI) == 1) {
+    if (!is.null(formatted_table$CI) && insight::n_unique(formatted_table$CI) == 1) {
       formatted_table$CI <- NULL
     }
 
@@ -735,8 +746,8 @@
     }
 
     # remove unique columns
-    if (.n_unique(formatted_table$Effects) == 1) formatted_table$Effects <- NULL
-    if (.n_unique(formatted_table$Group) == 1) formatted_table$Group <- NULL
+    if (insight::n_unique(formatted_table$Effects) == 1) formatted_table$Effects <- NULL
+    if (insight::n_unique(formatted_table$Group) == 1) formatted_table$Group <- NULL
 
     final_table <- c(final_table, list(formatted_table))
   }
