@@ -86,6 +86,8 @@ predict.parameters_efa <- function(object,
   }
   if (!is.null(names)) {
     names(out)[1:length(c(names))] <- names
+  } else {
+    names(out) <- names(get_scores(object))
   }
   row.names(out) <- NULL
   out
@@ -256,7 +258,7 @@ print.parameters_omega_summary <- function(x, ...) {
     type <- "principal component"
   } else if (type %in% c("fa")) {
     type <- "latent factor"
-  } else if (type %in% c("kmeans")) {
+  } else if (type %in% c("kmeans", "hclust", "pvclust", "dbscan", "mixture", "pam")) {
     type <- "cluster"
   } else {
     type <- paste0(type, " component")
@@ -402,3 +404,28 @@ sort.parameters_pca <- sort.parameters_efa
 
   loadings
 }
+
+
+
+# closest_component -------------------------------------------------------
+
+
+#' @rdname principal_components
+#' @export
+closest_component <- function(pca_results) {
+  if ("closest_component" %in% names(attributes(pca_results))) {
+    attributes(pca_results)$closest_component
+  } else {
+    .closest_component(pca_results)
+  }
+}
+
+
+
+.closest_component <- function(loadings, loadings_columns = NULL, variable_names = NULL) {
+  if (is.matrix(loadings)) loadings <- as.data.frame(loadings)
+  if (is.null(loadings_columns)) loadings_columns <- 1:ncol(loadings)
+  if (is.null(variable_names)) variable_names <- row.names(loadings)
+  component_columns <- apply(loadings[loadings_columns], 1, function(i) which.max(abs(i)))
+  stats::setNames(component_columns, variable_names)
+}
